:mod:`~kanon.units.radices` --- Arithmetic for any positional notation systems
==============================================================================

.. automodapi:: kanon.units.radices
    :inherited-members:
    :include-all-objects:
